@@ -1,13 +1,13 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
+
+from django.conf import settings
 from django import forms
-from django.utils.translation import ugettext_lazy as _
 
 from .models import Channel
 
 
 class ChannelAdminForm(forms.ModelForm):
-    layout = forms.ChoiceField(choices=(('default', _('Default')),))
+    layout = forms.ChoiceField(choices=settings.OPPS_CHANNEL_LAYOUT)
 
     def __init__(self, *args, **kwargs):
         super(ChannelAdminForm, self).__init__(*args, **kwargs)
