@@ -28,7 +28,7 @@ def upload_js(container=None):
         title + u"""' required></label>
         <label>""" + unicode(_(u'Caption')) + u""":
             <textarea name="caption" rows="2" colums="1">
-                        </textarea>
+                        </textarea></label>
         <label>""" + unicode(_(u'Order')) + u""": <input type="text"
         name="order" value="0"/></label>
         <label>""" + unicode(_(u'Source')) + u""":
@@ -94,7 +94,9 @@ def upload_js(container=None):
             </td>
             <td class="size">
             <span>{%=o.formatFileSize(file.size)%}</span></td>
-            <td colspan="2"></td>
+            <td class="success-message" colspan="2">
+                {%=locale.fileupload.success%}
+            </td>
         {% } %}
         <!-- td class="delete">
             <button class="btn btn-danger"
